//
// This command line utility converts space-separated values captured with Modscan32 into comma-separated values.
// To compile this with the free MinGW compiler for Windows, type this command: 
// mingw32-gcc -o csv.exe csv.c
//

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

int main(int argc, char* argv[])
{
  int i;
  FILE *fp, *outfp;
  char *infile;
  static char outfile[1024];
  static char line[32000];
  static char fld[32000];
  static char time[256];
  static char month[256];
  static int day;
  static int year;
  static long startReg;
  char *ptr;
  char *fldptr;

  if (argc != 2 && argc != 3) {
    printf("Usage: csv infile [outfile]\n");
    printf("where infile is space-separated data to be converted to CSV data.\n");
    printf("      outfile will contain the converted CSV data.\n");
    printf("      If outfile already exists, it will be overwritten!!!\n");
    printf("      If outfile is unspecified then the output will go to the same filename as infile with a \".csv\" extension.\n");
    exit(1);
  }
  infile = argv[1];
  if ((fp = fopen(infile, "rb")) == NULL) {
    fprintf(stderr, "Can't open input file, %s\n", infile);
    exit(1);
  }
  // If user specified an output file
  if (argc == 3) {
    strcpy(outfile, argv[2]);
  }
  else {
    strcpy(outfile, infile);
    strcat(outfile, ".csv");
  }
  if ((outfp = fopen(outfile, "wb")) == NULL) {
    fprintf(stderr, "Can't open output file, %s\n", outfile);
    exit(1);
  }
  while ((fgets(line, sizeof(line)-1, fp)) != NULL) {
    fldptr = line;

    // Parse time, month, year and startReg 
    if (sscanf(fldptr, "%s %s %d, %d %ld:", time, month, &day, &year, &startReg) == 5) {
      fprintf(outfp, "%s,%s-%d-%d,%ld,", time, month, day, year, startReg);
    }
    // Skip past time, month, year, startReg to first register data field
    while ((ptr = strstr(fldptr, ":")) != NULL) {
      fldptr = ptr + 1;
    }
    // Parse each data field and reformat as CSV
    while (sscanf(fldptr, "%s", fld) == 1) {
      fprintf(outfp, "%s,", fld);
      fldptr += strlen(fld);
      while (*fldptr == ' ' || *fldptr == '\t') {
        fldptr++;
      }
    }
    fprintf(outfp, "\n");
  }
  fclose(fp);
  fclose(outfp);
  exit(0);
}

